//
// C++ Interface: %{MODULE}
//
// Description: 
//
//
// Author: %{AUTHOR} <%{EMAIL}>, (C) %{YEAR}
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KPGSETOWNERWIZARD_H
#define KPGSETOWNERWIZARD_H

#include "kpg3stepswizard.h"

class KPGUsersFolder;

/**
  * Set owner Wizard
  *
  * @author Lumir Vanek
  */
class KPGSetOwnerWizard : public KPG3StepsWizard
{
	Q_OBJECT
public:
    KPGSetOwnerWizard(QWidget *parent, const char *name, KPGUsersFolder *, const char *, const QString &, const QString &);
    ~KPGSetOwnerWizard();

protected:
    virtual void showPage(QWidget *);

protected:
	QString m_strObjectTypeName; // TABLE, INDEX ...
	QString m_strNamespaceObjectName; // schema qualified object name
        
protected slots:
    virtual void languageChange(); 
};

#endif
